@@ -1,13 +1,13 @@
 import re
 import tempfile
 from pathlib import Path
-from typing import Tuple, List
+from typing import List, Tuple
 
 from robot.libraries.BuiltIn import BuiltIn
 from robot.parsing import get_model, get_resource_model
-from robot.running import TestSuite, ResourceFileBuilder
-from robot.running.model import If, For, While, Keyword, ResourceFile
+from robot.running import ResourceFileBuilder, TestSuite
 from robot.running.builder.transformers import ResourceBuilder
+from robot.running.model import For, If, Keyword, ResourceFile, While
 from robot.variables.search import is_variable
 
 from .robotlib import ImportedLibraryDocBuilder, get_libs
@@ -120,7 +120,9 @@ Fake Test
 
 
 def _import_resource_from_string(command):
-    with tempfile.NamedTemporaryFile(mode='w', prefix="keywords", suffix=".resource", encoding="utf-8") as res_file:
+    with tempfile.NamedTemporaryFile(
+        mode="w", prefix="keywords", suffix=".resource", encoding="utf-8"
+    ) as res_file:
         res_file.write(command)
         res_file.seek(0)
         global temp_resources
@@ -136,6 +138,7 @@ def _get_assignments(body_elem):
         for child in body_elem.body:
             yield from _get_assignments(child)
 
+
 def run_debug_if(condition, *args):
     """Runs DEBUG if condition is true."""
 
